# APP业务

js依赖

```html
<script src="static/form/js/app-oa-form-util.js?v="></script>
```

## 初始化

页面需要隐藏 `oa-form-footer-tool-bar`，由原生调用方法触发

> 页面加载 -> APP初始化

```js
appOaFormUtil.setForm(layui.form);
appOaFormUtil.initAppFormData(initObj);
```

参数

|名称|类型|说明|
|-|-|-|
|initObj|object|初始化对象|

initObj

|名称|类型|说明|
|-|-|-|
|confirmAssignees|array|[确认代理人](./app.md#代理人)列表|
|fields|array|[字段](./app.md#字段)列表|
|formButton|object|[表单按钮](./app.md#表单按钮)|
|currentUser|object|[当前用户](./app.md#当前用户)|

## 方法

### 字段赋值

> APP -> 页面字段

方法

```js
appOaFormUtil.setFieldValue(fieldName, fieldValue)
```

参数

|名称|类型|说明|参数值|
|-|-|-|-|
|fieldName|string|字段名|
|fieldValue|string|字段值|

### 附件赋值

方法

```js
appOaFormUtil.setAttachments(attachments)
```

参数

|名称|类型|说明|参数值|
|-|-|-|-|
|attachments|string|附件列表|格式：附件1,附件2。附件格式：ID:名称。英文冒号分割ID与名称，英文逗号分割组。名称不能有英文冒号与逗号|

### 抄送人赋值

方法

```js
appOaFormUtil.setCcs(ccs)
```

参数

|名称|类型|说明|参数值|
|-|-|-|-|
|ccs|string|抄送人列表|格式：抄送人ID1,抄送人ID2。英文逗号分割。|

### 提交表单

```js
appOaFormUtil.submitFormReport(btnIndex);
```

参数

|名称|类型|说明|参数值|
|-|-|-|-|
|btnIndex|int|按钮的下标||

## 事件

### 回退

- Method: **PUT**

- Content-Type: `application/json`

- URL：`app/oa-form-report/update-go-back/process-instance-id/{processInstanceId}/task-id/{taskId}/node-id/{nodeId}`

- PathParams: 

|参数|说明|
|-|-|
|processInstanceId|流程实例ID|
|taskId|当前任务ID|
|nodeId|回退到的节点ID|

- Headers: 

```json
{
    token: token
}
```

- RequestBody: 

```json
{
    reason: "原因"
}
```

- Response

状态码

|名称|值|
|-|-|
|200|请求成功|
|400|请求错误|
|401|权限不足|
|403|访问禁止|
|500|系统错误|

Body：

```json
{
    code: "错误编码",
    msg: "错误原因"
}
```

### 强制结束

- Method: **PUT**

- Content-Type: `application/json`

- URL：`app/oa-form-report/update-forced-end/process-instance-id/{processInstanceId}/task-id/{taskId}`

- PathParams: 

|参数|说明|
|-|-|
|processInstanceId|流程实例ID|
|taskId|当前任务ID|

- Headers: 

```json
{
    token: token
}
```

- RequestBody: 

```json
{
    reason: "原因"
}
```
- Response

状态码

|名称|值|
|-|-|
|200|请求成功|
|400|请求错误|
|401|权限不足|
|403|访问禁止|
|500|系统错误|

Body：

```json
{
    code: "错误编码",
    msg: "错误原因"
}
```

### 转交

- Method: **PUT**

- Content-Type: `application/json`

- URL：`app/oa-form-report/update-assignee/process-instance-id/{processInstanceId}/task-id/{taskId}`

- PathParams: 

|参数|说明|
|-|-|
|processInstanceId|流程实例ID|
|taskId|当前任务ID|

- Headers: 

```json
{
    token: token
}
```

- RequestBody: 

```json
{
    assignee: "接收人ID",
    reason: "原因"
}
```

- Response

状态码

|名称|值|
|-|-|
|200|请求成功|
|400|请求错误|
|401|权限不足|
|403|访问禁止|
|500|系统错误|

Body：

```json
{
    code: "错误编码",
    msg: "错误原因"
}
```

## 对象说明

### 代理人

|属性|类型|说明|参数值|
|-|-|-|-|
|assignees|Array|[代理人用户](./app.md#代理人用户)列表||
|btnExc|string|按钮条件||
|btnText|string|按钮名称||
|nextEndEvent|boolean|下节点是否为结束节点|true：是，false：否|
|nodeType|string|节点类型|normal：普通（单实例）节点，multiple：多实例节点|

### 代理人用户

|属性|类型|说明|参数值|
|-|-|-|-|
|userId|string|用户ID||
|userName|string|用户昵称||
|userUsername|string|用户名||
|avatar|string|头像ID||

### 字段

|属性|类型|说明|参数值|
|-|-|-|-|
|fieldName|string|字段名称||
|isEditable|int|可编辑|0：否，1：是|
|isVisible|int|可显示|0：否，1：是|
|editHistory|string|编辑历史|noRecord：不记录（默认），latest：记录最新（签批），all：记录全部（会签）
|autoBackFill|string|自动回填|noBackFill：不回填（默认），currentUserName：当前用户名，currentUserDepartment：当前用户部门|

### 表单按钮

|属性|类型|说明|参数值|
|-|-|-|-|
|btnAttachment|int|附件按钮|0：未激活，1：已激活|
|btnForcedEnd|int|强制结束按钮|0：未激活，1：已激活|
|btnPrint|int|打印按钮|0：未激活，1：已激活
|btnCc|int|抄送按钮|0：未激活，1：已激活|
|btnGoBack|int|回退按钮|0：未激活，1：已激活|
|btnTransfer|int|转交按钮|0：未激活，1：已激活|
|goBackUserTasks|array|[历史任务](./app.md#历史任务)列表（按执行顺序），当 <kbd>btnGoBack</kbd> 激活时有效||

### 历史任务

|属性|类型|说明|参数值|
|-|-|-|-|
|nodeId|string|节点ID||
|taskName|string|任务名称||

### 当前用户

|属性|类型|说明|参数值|
|-|-|-|-|
|userId|string|用户ID||
|userName|string|用户名||
|departments|array|[用户部门](./app.md#用户部门)列表||

### 用户部门

|属性|类型|说明|参数值|
|-|-|-|-|
|departmentId|string|部门ID||
|departmentParentId|string|部门上级ID||
|departmentName|string|部门名称||
|departmentCode|string|部门编码||
|departmentNo|string|部门编号||